#       Licensed to the Apache Software Foundation (ASF) under one
#       or more contributor license agreements.  See the NOTICE file
#       distributed with this work for additional information
#       regarding copyright ownership.  The ASF licenses this file
#       to you under the Apache License, Version 2.0 (the
#       "License"); you may not use this file except in compliance
#       with the License.  You may obtain a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#       Unless required by applicable law or agreed to in writing,
#       software distributed under the License is distributed on an
#       "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
#       KIND, either express or implied.  See the License for the
#       specific language governing permissions and limitations
#       under the License.

from tg import app_globals as g
from activitystream.storage.mingstorage import Activity

from allura.lib.decorators import task


@task
def create_timelines(node_id):
    g.director.create_timelines(node_id)


@task
def change_user_name(user_id, new_name):
    Activity.query.update(
        {'actor.node_id': f"User:{user_id}"},
        {'$set': {
            "actor.activity_name": new_name,
        }},
        multi=True
    )
